@@ -12,7 +12,7 @@ class TacviewCli:
         parser = argparse.ArgumentParser(
             description='Tacview-Client CLI',
             usage="Run one of: [client, createdb dropdb]")
-        parser.add_argument('command', choices= ['client', 'dropdb', 'createdb'],
+        parser.add_argument('command', choices= ['client', 'serve', 'dropdb', 'createdb'],
                             help='Subcommand to invoke')
         args = parser.parse_args(sys.argv[1:2])
         if not hasattr(self, args.command):
@@ -21,6 +21,8 @@ class TacviewCli:
             sys.exit(1)
         getattr(self, args.command)()
 
+    def serve(sefl)
+
     def client(self):
         """CLI for tacview client reader."""
         parser = argparse.ArgumentParser(prog="tacview",
@@ -68,7 +70,7 @@ class TacviewCli:
                             max_iters=None,
                             batch_size=args.batch_size,
                             dsn=args.postgres_dsn)
-                server_proc.join()
+                server_proc.terminate()
         except KeyboardInterrupt:
             print("tacview-client shutting down...")
         except Exception as err:
