@@ -663,6 +663,7 @@ async def consumer(host: str,
     init_time = time.time()
     lines_read = 0
     last_log = float(0.0)
+    print_log = float(0.0)
     line_proc_time = float(0.0)
     while True:
         try:
@@ -679,13 +680,20 @@ async def consumer(host: str,
 
                 runtime = time.time() - init_time
                 log_check = runtime - last_log
+                print_check = runtime - print_log
                 if log_check > 0.05:
                     ln_sec = lines_read / runtime
                     sys.stdout.write("\rEvents processed: {:,} at {:,.2f} events/sec".format(
                         lines_read, ln_sec))
                     sys.stdout.flush()
-
                     last_log = runtime
+
+                    if print_check < 10:
+                        LOG.info("Events processed: {:,} at {:,.2f} events/sec".format(
+                            lines_read, ln_sec))
+                        print_log = runtime
+
+
             else:
                 t1 = time.time()
                 obj = await line_to_obj(obj, sock)
